lists.openwall.net   lists  /  announce  owl-users  owl-dev  john-users  john-dev  passwdqc-users  yescrypt  popa3d-users  /  oss-security  kernel-hardening  musl  sabotage  tlsify  passwords  /  crypt-dev  xvendor  /  Bugtraq  Full-Disclosure  linux-kernel  linux-netdev  linux-ext4  linux-hardening  linux-cve-announce  PHC 
Open Source and information security mailing list archives
 
Hash Suite: Windows password security audit tool. GUI, reports in PDF.
[<prev] [next>] [thread-next>] [day] [month] [year] [list]
Date: Thu, 18 Apr 2024 22:56:49 -0700
From: Erni Sri Satya Vennela <ernis@...ux.microsoft.com>
To: kys@...rosoft.com,
	haiyangz@...rosoft.com,
	wei.liu@...nel.org,
	decui@...rosoft.com,
	linux-hyperv@...r.kernel.org,
	linux-kernel@...r.kernel.org
Cc: ernis@...rosoft.com,
	Erni Sri Satya Vennela <ernis@...ux.microsoft.com>
Subject: [PATCH] hv/vmbus_drv: rename hv_acpi_init() to vmbus_init()

As the driver now supports both ACPI and DeviceTree,
rename hv_acpi_init() to vmbus_init() and
change comments accordingly.

Signed-off-by: Erni Sri Satya Vennela <ernis@...ux.microsoft.com>
---
 drivers/hv/vmbus_drv.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/drivers/hv/vmbus_drv.c b/drivers/hv/vmbus_drv.c
index 12a707ab73f8..e140cbf8d4c7 100644
--- a/drivers/hv/vmbus_drv.c
+++ b/drivers/hv/vmbus_drv.c
@@ -2609,7 +2609,7 @@ static struct syscore_ops hv_synic_syscore_ops = {
 	.resume = hv_synic_resume,
 };
 
-static int __init hv_acpi_init(void)
+static int __init vmbus_init(void)
 {
 	int ret;
 
@@ -2620,7 +2620,7 @@ static int __init hv_acpi_init(void)
 		return 0;
 
 	/*
 	 * Get ACPI resources first.
 	 */
 	ret = platform_driver_register(&vmbus_platform_driver);
 	if (ret)
@@ -2707,5 +2707,5 @@ static void __exit vmbus_exit(void)
 MODULE_LICENSE("GPL");
 MODULE_DESCRIPTION("Microsoft Hyper-V VMBus Driver");
 
-subsys_initcall(hv_acpi_init);
+subsys_initcall(vmbus_init);
 module_exit(vmbus_exit);
@@ -2620,7 +2620,7 @@ static int __init hv_acpi_init(void)
 
 	/*
-	 * Get ACPI resources first.
+	 * Get VMBus resources first.
 	 */
 	ret = platform_driver_register(&vmbus_platform_driver);
-- 
2.34.1


Powered by blists - more mailing lists

Powered by Openwall GNU/*/Linux Powered by OpenVZ